import requests
from dateutil.parser import parse
import re


def is_date(string, fuzzy=False):
    """
    Return whether the string can be interpreted as a date.

    :param string: str, string to check for date
    :param fuzzy: bool, ignore unknown tokens in string if True
    """
    try:
        parse(string, fuzzy=fuzzy)
        return True

    except ValueError:
        return False


def is_url(link):
    """
    Checks if a supplied string is a valid url
    """
    regex = re.compile(
        r'^(?:http|ftp)s?://'  # http:// or https://
        # domain...
        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'
        r'localhost|'  # localhost...
        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
        r'(?::\d+)?'  # optional port
        r'(?:/?|[/?]\S+)$', re.IGNORECASE)
    return re.match(regex, link) is not None


def send_request(url, method, payload=None, headers=None, file=None):
    request_body = {}
    files = {}
    header = {}

    if payload:
        request_body.update(payload)
    if headers:
        header.update(headers)
    if file:
        files.update(file)

    response = requests.request(
        method, url, headers=header, data=request_body, files=files)

    return response



import requests
import re
from .utils import is_date, send_request


def send_sms(userid, password,  senderid, output, duplicatecheck, msg: str, **kwargs):
    extr = kwargs
    url = "https://portal.zettatel.com/SMSApi/send"

    payload = {'userid': userid,
               'password': password,
               'senderid': senderid,
               'msg': msg,
               'sendMethod': 'quick',
               'msgType': 'text',
               'output': output,
               'duplicatecheck': duplicatecheck}

    if kwargs.get('group'):
        payload['group'] = extr['group']

    elif kwargs.get('to'):
        payload['mobile'] = extr['to']

    if extr.get('scheduleTime'):
        if is_date(extr['scheduleTime']):
            payload['scheduleTime'] = extr['scheduleTime']
        else:
            return ValueError("Invalid date and time")
    elif extr.get('smartLinkTitle'):
        payload['smartLinkTitle'] = extr['smartLinkTitle']

    files = [

    ]
    headers = {}

    response = requests.request(
        "POST", url, headers=headers, data=payload, files=files)

    print(response.text)

    return response



from setuptools import setup

setup(
    name='zettatel',
    version='0.1.01',
    description='a python package to help send messages using the Zettatel API',
    url='https://github.com/levin-mutai/zettatel',
    author='Levin Mutai',
    author_email='levinmutai2@gmail.com',
    license='MIT licence',
    packages=['messages'],
    install_requires=['build == 0.10.0',
                      'certifi ',
                      'charset-normalizer == 3.0.1',
                      'click == 8.1.3',
                      'idna == 3.4',
                      'packaging == 23.0',
                      'pip-tools == 6.12.2',
                      'pyproject_hooks == 1.0.0',
                      'python-dateutil == 2.8.2',
                      'python-dotenv == 0.21.1',
                      'requests == 2.28.2',
                      'six == 1.16.0',
                      'tomli == 2.0.1',
                      'urllib3 == 1.26.14'
                      ],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
    ],
)
